from .animals import (
    cat_says,
    dog_says,
    frog_says,
    fox_says,
    cow_says,
    pig_says,
    owl_says,
    bat_says,
    dolphin_says,
    shark_says,
    elephant_says,
    bunny_says,
    spider_says,
    horse_says,
    monkey_says,
    wolf_says
)
